@@ -21,10 +21,15 @@ use Travel::Status::DE::HAFAS::Polyline qw(decode_polyline);
 use Travel::Status::DE::HAFAS::Product;
 use Travel::Status::DE::HAFAS::StopFinder;
 
-our $VERSION = '6.00';
+our $VERSION = '6.01';
 
 # {{{ Endpoint Definition
 
+# Most of these have been adapted from
+# <https://github.com/public-transport/transport-apis> and
+# <https://github.com/public-transport/hafas-client/tree/main/p>.
+# Many thanks to Jannis R / @derhuerst and all contributors for maintaining
+# these resources.
 my %hafas_instance = (
 	AVV => {
 		stopfinder  => 'https://auskunft.avv.de/bin/ajax-getstop.exe',
@@ -90,6 +95,77 @@ my %hafas_instance = (
 			lang => 'en',
 		},
 	},
+	BLS => {
+		mgate       => 'https://bls.hafas.de/bin/mgate.exe',
+		stopfinder  => 'https://bls.hafas.de/bin/ajax-stopfinder.exe',
+		name        => 'BLS AG',
+		time_zone   => 'Europe/Zurich',
+		productbits => [
+			[ ice   => 'long distance trains' ],
+			[ ic_ec => 'long distance trains' ],
+			[ ir    => 'inter-regio trains' ],
+			[ regio => 'regional trains' ],
+			[ ferry => 'maritime transit' ],
+			[ s     => 'suburban trains' ],
+			[ bus   => 'busses' ],
+			[ fun   => 'funicular / gondola' ],
+			[ _     => undef ],
+			[ tram  => 'trams' ],
+			[ _     => undef ],
+			[ _     => undef ],
+			[ car   => 'Autoverlad' ]
+		],
+		languages => [qw[de fr it en]],
+		request   => {
+			client => {
+				id   => 'HAFAS',
+				type => 'WEB',
+				name => 'webapp',
+			},
+			ver  => '1.46',
+			auth => {
+				type => 'AID',
+				aid  => '3jkAncud78HSo' . 'qclmN54812A',
+			},
+			lang => 'deu',
+		},
+	},
+	CMTA => {
+		stopfinder  => 'https://capmetro.hafas.cloud/bin/ajax-getstop.exe',
+		mgate       => 'https://capmetro.hafas.cloud/bin/mgate.exe',
+		name        => 'Capital Metropolitan Transportation Authority',
+		time_zone   => 'America/Chicago',
+		productbits => [
+			[ _     => undef ],
+			[ _     => undef ],
+			[ _     => undef ],
+			[ regio => 'MetroRail' ],
+			[ _     => undef ],
+			[ bus   => 'MetroBus' ],
+			[ _     => undef ],
+			[ _     => undef ],
+			[ _     => undef ],
+			[ _     => undef ],
+			[ _     => undef ],
+			[ _     => undef ],
+			[ rapid => 'MetroRapid' ],
+		],
+		languages => [qw[en]],
+		request   => {
+			client => {
+				id   => 'CMTA',
+				type => 'IPH',
+				name => 'CapMetro',
+				v    => 2,
+			},
+			ver  => '1.40',
+			auth => {
+				type => 'AID',
+				aid  => 'ioslaskd' . 'cndrjcmlsd',
+			},
+			lang => 'en',
+		},
+	},
 	DB => {
 		stopfinder    => 'https://reiseauskunft.bahn.de/bin/ajax-getstop.exe',
 		mgate         => 'https://reiseauskunft.bahn.de/bin/mgate.exe',
@@ -1140,7 +1216,7 @@ monitors
 
 =head1 VERSION
 
-version 6.00
+version 6.01
 
 =head1 DESCRIPTION
 
@@ -1445,17 +1521,10 @@ The non-default services (anything other than DB) are not well tested.
 
 =over
 
-=item * Travel::Status::DE::HAFAS::Journey(3pm)
+=item * L<https://dbf.finalrewind.org?hafas=1> provides a web frontend to most
+of this module's features. Set B<hafas=>I<service> to use a specific service.
 
-=item * Travel::Status::DE::HAFAS::Location(3pm)
-
-=item * Travel::Status::DE::HAFAS::Message(3pm)
-
-=item * Travel::Status::DE::HAFAS::Product(3pm)
-
-=item * Travel::Status::DE::HAFAS::StopFinder(3pm)
-
-=item * Travel::Status::DE::HAFAS::Stop(3pm)
+=item * Travel::Routing::DE::HAFAS(3pm) for itineraries.
 
 =back
 
